@@ -3,7 +3,7 @@ package Net::DNS::DomainName;
 use strict;
 use warnings;
 
-our $VERSION = (qw$Id: DomainName.pm 1855 2021-11-26 11:33:48Z willem $)[2];
+our $VERSION = (qw$Id: DomainName.pm 1898 2023-02-15 14:27:22Z willem $)[2];
 
 
 =head1 NAME
@@ -97,7 +97,9 @@ sub decode {
 	my $self   = bless {label => $label}, shift;
 	my $buffer = shift;					# reference to data buffer
 	my $offset = shift || 0;				# offset within buffer
-	my $cache  = shift || {};				# hashed objectref by offset
+	my $linked = shift;					# caller's compression index
+	my $cache  = $linked;
+	$cache->{$offset} = $self;				# hashed objectref by offset
 
 	my $buflen = length $$buffer;
 	my $index  = $offset;
@@ -116,9 +118,10 @@ sub decode {
 		} else {					# compression pointer
 			my $link = 0x3FFF & unpack( "\@$index n", $$buffer );
 			croak 'corrupt compression pointer' unless $link < $offset;
+			croak 'invalid compression pointer' unless $linked;
 
 			# uncoverable condition false
-			$self->{origin} = $cache->{$link} ||= Net::DNS::DomainName->decode( $buffer, $link, $cache );
+			$self->{origin} = $cache->{$link} ||= __PACKAGE__->decode( $buffer, $link, $cache );
 			return wantarray ? ( $self, $index + 2 ) : $self;
 		}
 	}
@@ -276,8 +279,11 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::Domain>, RFC1035, RFC2535,
-RFC3597, RFC4034
+L<perl> L<Net::DNS> L<Net::DNS::Domain>
+L<RFC1035|https://tools.ietf.org/html/rfc1035>
+L<RFC2535|https://tools.ietf.org/html/rfc2535>
+L<RFC3597|https://tools.ietf.org/html/rfc3597>
+L<RFC4034|https://tools.ietf.org/html/rfc4034>
 
 =cut
 
