@@ -1,22 +1,18 @@
 package Net::DNS::RR::NAPTR;
 
-#
-# $Id: NAPTR.pm 1528 2017-01-18 21:44:58Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: NAPTR.pm 1898 2023-02-15 14:27:22Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::NAPTR - DNS NAPTR resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
@@ -24,97 +20,91 @@ use Net::DNS::Text;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset, @opaque ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	@{$self}{qw(order preference)} = unpack "\@$offset n2", $$data;
-	( $self->{flags},   $offset ) = decode Net::DNS::Text( $data, $offset + 4 );
-	( $self->{service}, $offset ) = decode Net::DNS::Text( $data, $offset );
-	( $self->{regexp},  $offset ) = decode Net::DNS::Text( $data, $offset );
-	$self->{replacement} = decode Net::DNS::DomainName2535( $data, $offset, @opaque );
+	( $self->{flags},   $offset ) = Net::DNS::Text->decode( $data, $offset + 4 );
+	( $self->{service}, $offset ) = Net::DNS::Text->decode( $data, $offset );
+	( $self->{regexp},  $offset ) = Net::DNS::Text->decode( $data, $offset );
+	$self->{replacement} = Net::DNS::DomainName2535->decode( $data, $offset );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-	my ( $offset, @opaque ) = @_;
+	my ( $self, $offset, @opaque ) = @_;
 
-	return '' unless defined $self->{replacement};
 	my $rdata = pack 'n2', @{$self}{qw(order preference)};
 	$rdata .= $self->{flags}->encode;
 	$rdata .= $self->{service}->encode;
 	$rdata .= $self->{regexp}->encode;
 	$rdata .= $self->{replacement}->encode( $offset + length($rdata), @opaque );
+	return $rdata;
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless defined $self->{replacement};
 	my @order = @{$self}{qw(order preference)};
-	my @rdata = ( @order, map $_->string, @{$self}{qw(flags service regexp replacement)} );
+	my @rdata = ( @order, map { $_->string } @{$self}{qw(flags service regexp replacement)} );
+	return @rdata;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	foreach (qw(order preference flags service regexp replacement)) { $self->$_(shift) }
+	foreach (qw(order preference flags service regexp replacement)) { $self->$_( shift @argument ) }
+	return;
 }
 
 
 sub order {
-	my $self = shift;
-
-	$self->{order} = 0 + shift if scalar @_;
-	$self->{order} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{order} = 0 + $_ }
+	return $self->{order} || 0;
 }
 
 
 sub preference {
-	my $self = shift;
-
-	$self->{preference} = 0 + shift if scalar @_;
-	$self->{preference} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{preference} = 0 + $_ }
+	return $self->{preference} || 0;
 }
 
 
 sub flags {
-	my $self = shift;
-
-	$self->{flags} = new Net::DNS::Text(shift) if scalar @_;
-	$self->{flags}->value if $self->{flags};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{flags} = Net::DNS::Text->new($_) }
+	return $self->{flags} ? $self->{flags}->value : undef;
 }
 
 
 sub service {
-	my $self = shift;
-
-	$self->{service} = new Net::DNS::Text(shift) if scalar @_;
-	$self->{service}->value if $self->{service};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{service} = Net::DNS::Text->new($_) }
+	return $self->{service} ? $self->{service}->value : undef;
 }
 
 
 sub regexp {
-	my $self = shift;
-
-	$self->{regexp} = new Net::DNS::Text(shift) if scalar @_;
-	$self->{regexp}->value if $self->{regexp};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{regexp} = Net::DNS::Text->new($_) }
+	return $self->{regexp} ? $self->{regexp}->value : undef;
 }
 
 
 sub replacement {
-	my $self = shift;
-
-	$self->{replacement} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{replacement}->name if $self->{replacement};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{replacement} = Net::DNS::DomainName2535->new($_) }
+	return $self->{replacement} ? $self->{replacement}->name : undef;
 }
 
 
 my $function = sub {
 	my ( $a, $b ) = ( $Net::DNS::a, $Net::DNS::b );
-	$a->{order} <=> $b->{order}
+	return $a->{order} <=> $b->{order}
 			|| $a->{preference} <=> $b->{preference};
 };
 
@@ -130,7 +120,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name NAPTR order preference flags service regexp replacement');
+    $rr = Net::DNS::RR->new('name NAPTR order preference flags service regexp replacement');
 
 =head1 DESCRIPTION
 
@@ -216,7 +206,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -233,6 +223,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC2915, RFC2168, RFC3403
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC3403|https://tools.ietf.org/html/rfc3403>
 
 =cut
